package com.staffing.custom.service;

import com.staffing.custom.domain.StEmployeeFundRecord;
import com.staffing.custom.param.FxParam;

import java.util.List;

/**
 * 员工资金流水Service接口
 * 
 * @author staffing
 * @date 2024-08-27
 */
public interface IStEmployeeFundRecordService 
{
    /**
     * 查询员工资金流水
     * 
     * @param id 员工资金流水主键
     * @return 员工资金流水
     */
    public StEmployeeFundRecord selectStEmployeeFundRecordById(Long id);

    /**
     * 查询员工资金流水列表
     * 
     * @param stEmployeeFundRecord 员工资金流水
     * @return 员工资金流水集合
     */
    public List<StEmployeeFundRecord> selectStEmployeeFundRecordList(StEmployeeFundRecord stEmployeeFundRecord);

    /**
     * 新增员工资金流水
     * 
     * @param stEmployeeFundRecord 员工资金流水
     * @return 结果
     */
    public int insertStEmployeeFundRecord(StEmployeeFundRecord stEmployeeFundRecord);

    /**
     * 修改员工资金流水
     * 
     * @param stEmployeeFundRecord 员工资金流水
     * @return 结果
     */
    public int updateStEmployeeFundRecord(StEmployeeFundRecord stEmployeeFundRecord);

    /**
     * 批量删除员工资金流水
     * 
     * @param ids 需要删除的员工资金流水主键集合
     * @return 结果
     */
    public int deleteStEmployeeFundRecordByIds(Long[] ids);

    /**
     * 删除员工资金流水信息
     * 
     * @param id 员工资金流水主键
     * @return 结果
     */
    public int deleteStEmployeeFundRecordById(Long id);

    String importRecord(List<StEmployeeFundRecord> userList);

    String faxin(FxParam fxParam);
}
